# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2009 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.

import os
from setuptools import setup
from elisa.core.utils.dist import find_packages, TrialTest, Clean

packages, package_dir = find_packages(os.path.dirname(__file__))
cmdclass = dict(test=TrialTest, clean=Clean)

#FIXME: add dependency on storm/twisted-wrapper

setup(name='elisa-plugin-database',
    version='0.12', 
    description="Database management",
    long_description="""Scan your local media and index it in the database.""",
    license='GPLv3', 
    author='Elisa Developers',
    author_email='elisa@lists.fluendo.com',
    keywords='',
    namespace_packages=['elisa', 'elisa.plugins'],
    packages=packages,
    package_dir=package_dir,
    entry_points="""
    [elisa.plugins.search.searchers]
    DBSearcher = elisa.plugins.database.searcher:DBSearcher

    [elisa.core.components.resource_provider]
    MediaScanner = elisa.plugins.database.media_scanner:MediaScanner
    
    [elisa.core.components.service_provider]
    DatabaseDBusServiceProvider = elisa.plugins.database.dbus_service:DatabaseDBusServiceProvider
    """,
    package_data={'': ['*.png', '*.conf'],
                  'elisa.plugins.database.i18n': ['*/LC_MESSAGES/*.[m|p]o', '*.pot'],
                 },
    controller_mappings=[
                         # FIXME: we should create a controller path convention
                         # and adapt the pathes here
                         ('/poblesec/database/music/artists',
                          'elisa.plugins.database.music_controller:ArtistsDbListSwitcherController'),
                         ('/poblesec/database/music/albums',
                          'elisa.plugins.database.music_controller:AlbumsDbListSwitcherController'),
                         ('/poblesec/database/music/albums_of_artist',
                          'elisa.plugins.database.music_controller:AlbumsOfArtistDbListSwitcherController'),
                         ('/poblesec/database/music/tracks',
                          'elisa.plugins.database.music_controller:TracksDbListSwitcherController'),
                         ('/poblesec/database/music/genres',
                          'elisa.plugins.database.music_controller:GenresDbListSwitcherController'),
                         ('/poblesec/database/music/genre',
                          'elisa.plugins.database.music_controller:GenreDbListSwitcherController'),
                         ('/poblesec/database/music/decades',
                          'elisa.plugins.database.music_controller:DecadesDbListSwitcherController'),
                         ('/poblesec/database/music/time',
                          'elisa.plugins.database.music_controller:TimeDbListSwitcherController'),
                         ('/poblesec/database/music/tracks_played',
                          'elisa.plugins.database.playlists_controller:PlayedTracksListSwitcherController'),
                         ('/poblesec/database/video/video_added',
                          'elisa.plugins.database.playlists_controller:AddedVideoListSwitcherController'),
                         ('/poblesec/database/video/video_played',
                          'elisa.plugins.database.playlists_controller:PlayedVideoListSwitcherController'),
                         ('/poblesec/database/video/video_unplayed',
                          'elisa.plugins.database.playlists_controller:UnPlayedVideoListSwitcherController'),
                         ('/poblesec/database/music/tracks_added',
                          'elisa.plugins.database.playlists_controller:AddedTracksListSwitcherController'),
                         ('/poblesec/database/photo/list',
                          'elisa.plugins.database.photo_controller:PhotoListSwitcherController'),
                         ('/poblesec/database/photo/photo_actions',
                          'elisa.plugins.database.photo_controller:PhotoVerticalWithPreview'),
                         ('/poblesec/database/photo/albums',
                          'elisa.plugins.database.photo_controller:AlbumsListSwitcherController'),
                         ('/poblesec/database/photo/by_month',
                          'elisa.plugins.database.photo_controller:PhotoMonthListSwitcherController'),
                         ('/poblesec/database/photo/by_date',
                          'elisa.plugins.database.photo_controller:PhotoTimesListSwitcherController'),
                         ('/poblesec/database/photo/photos_added',
                          'elisa.plugins.database.playlists_controller:AddedPhotosListSwitcherController'),
                         ('/poblesec/database/photo/photos_played',
                          'elisa.plugins.database.playlists_controller:PlayedPhotosListSwitcherController'),
                         ('/poblesec/database/video/list',
                          'elisa.plugins.database.video_controller:AllVideosListSwitcherController'),
                         ('/poblesec/database/video/unclassified',
                          'elisa.plugins.database.video_controller:UnclassifiedVideosListSwitcherController'),
                         ('/poblesec/database/video/recategorize',
                          'elisa.plugins.database.video_categorizer:CategoryVerticalWithPreview'),
                         ('/poblesec/database/recategorize/confirm/unclassified',
                          'elisa.plugins.database.video_categorizer:UnclassifiedConfirmController'),
                         ('/poblesec/database/recategorize/movie',
                          'elisa.plugins.database.video_categorizer:MovieRecategorizerVerticalWithPreview'),
                         ('/poblesec/database/recategorize/search/movie',
                          'elisa.plugins.database.video_categorizer:MovieSearchController'),
                         ('/poblesec/database/recategorize/confirm/movie',
                          'elisa.plugins.database.video_categorizer:MovieConfirmController'),
                         ('/poblesec/database/recategorize/manual/movie',
                          'elisa.plugins.database.video_categorizer:MovieManualRecategorizer'),
                         ('/poblesec/database/recategorize/manual/tvshow',
                          'elisa.plugins.database.video_categorizer:TVShowManualRecategorizer'),
                         ('/poblesec/database/recategorize/manual/tvshow/season',
                          'elisa.plugins.database.video_categorizer:TVSeasonManualRecategorizer'),
                         ('/poblesec/database/recategorize/manual/tvshow/season/episode',
                          'elisa.plugins.database.video_categorizer:TVEpisodeNumberManualRecategorizer'),
                         ('/poblesec/database/recategorize/manual/tvshow/season/episode/title',
                          'elisa.plugins.database.video_categorizer:TVEpisodeTitleManualRecategorizer'),
                         ('/poblesec/database/recategorize/tvshow',
                          'elisa.plugins.database.video_categorizer:TVShowRecategorizerVerticalWithPreview'),
                         ('/poblesec/database/recategorize/tvshow/season',
                          'elisa.plugins.database.video_categorizer:TVSeasonRecategorizerVerticalWithPreview'),
                         ('/poblesec/database/recategorize/tvshow/season/episode',
                          'elisa.plugins.database.video_categorizer:TVEpisodeRecategorizerVerticalWithPreview'),
                         ('/poblesec/database/recategorize/confirm/tvshow',
                          'elisa.plugins.database.video_categorizer:TVShowConfirmController'),
                         ('/poblesec/database/recategorize/search/tvshow',
                          'elisa.plugins.database.video_categorizer:TVShowSearchController'),
                         ('/poblesec/database/movie/list',
                          'elisa.plugins.database.video_controller:AllMoviesListSwitcherController'),
                         ('/poblesec/database/tvshows/list',
                          'elisa.plugins.database.tvshows_controllers:AllTVSeasonsListSwitcherController'),
                         ('/poblesec/database/tvseason/list',
                          'elisa.plugins.database.tvshows_controllers:TVSeasonListSwitcherController'),
                         ('/poblesec/database/video/by_month',
                          'elisa.plugins.database.video_controller:VideosMonthListSwitcherController'),
                         ('/poblesec/database/video/by_date',
                          'elisa.plugins.database.video_controller:VideoTimesListSwitcherController'),
                         ('/poblesec/database/video/track',
                          'elisa.plugins.database.video_controller:VideoTrackListSwitcherController'),
                         ('/poblesec/database/movie/track',
                          'elisa.plugins.database.video_controller:MovieTrackListSwitcherController'),
                         ('/poblesec/database/movie/synopsis',
                          'elisa.plugins.database.video_controller:MovieSynopsisController'),
                         ('/poblesec/database/tvepisode/track',
                          'elisa.plugins.database.tvshows_controllers:TVEpisodeTrackListSwitcherController'),
                         ('/poblesec/database/tvepisode/synopsis',
                          'elisa.plugins.database.tvshows_controllers:TVEpisodeSynopsisController'),
                         ('/poblesec/database/.*playlists',
                          'elisa.plugins.poblesec.section:SectionMenuController'),
                         ('/poblesec/database/.*library',
                          'elisa.plugins.poblesec.section:SectionMenuController'),

                         ('/poblesec/search/results/DBSearcher/artists',
                          'elisa.plugins.database.music_controller:ArtistsDbListSwitcherController'),
                         ('/poblesec/search/results/DBSearcher/albums',
                          'elisa.plugins.database.music_controller:AlbumsDbListSwitcherController'),
                         ('/poblesec/search/results/DBSearcher/tracks',
                          'elisa.plugins.database.music_controller:TracksDbListSwitcherController'),],
    decorator_mappings=[
                        # FIXME: the filesystem decorator should not be here
                        # but in the poblesec plugin ; this works around an
                        # ordering issue in the menus.
                        ('/poblesec/database/music_library',
                        'elisa.plugins.poblesec.music:filesystem_decorator'),
                        ('/poblesec/database/video_library',
                        'elisa.plugins.poblesec.video:filesystem_decorator'),
                        # music library entries
                        ('/poblesec/database/music_library',
                         'elisa.plugins.database.music_controller:music_lib_decades_decorator'),
                        ('/poblesec/database/music_library',
                         'elisa.plugins.database.music_controller:music_lib_genres_decorator'),
                        ('/poblesec/database/music_library',
                         'elisa.plugins.database.music_controller:music_lib_tracks_decorator'),
                        ('/poblesec/database/music_library',
                         'elisa.plugins.database.music_controller:music_lib_albums_decorator'),
                        ('/poblesec/database/music_library',
                         'elisa.plugins.database.music_controller:music_lib_artists_decorator'),
                        # FIXME: this decorator should not be here but in the
                        # poblesec plugin; this works around an ordering issue
                        # in the menus.
                        ('/poblesec/database/music_library',
                         'elisa.plugins.poblesec.music:search_decorator'),
                        # FIXME: this decorator should not be here but in the
                        # poblesec plugin; this works around an ordering issue
                        # in the menus.
                        ('/poblesec/database/photo_library',
                        'elisa.plugins.poblesec.pictures:filesystem_decorator'),
                        # images
                        ('/poblesec/database/photo_library',
                         'elisa.plugins.database.photo_controller:photo_lib_month_decorator'),
                        ('/poblesec/database/photo_library',
                         'elisa.plugins.database.photo_controller:photo_lib_images_decorator'),
                        ('/poblesec/database/photo_library',
                         'elisa.plugins.database.photo_controller:photo_lib_albums_decorator'),
                        # videos library
                        ('/poblesec/database/video_library',
                         'elisa.plugins.database.video_controller:video_lib_unclassified_videos_decorator'),
                        ('/poblesec/database/video_library',
                         'elisa.plugins.database.video_controller:video_lib_all_movies_decorator'),
                        ('/poblesec/database/video_library',
                         'elisa.plugins.database.tvshows_controllers:tvshows_lib_decorator'),
                         # videos playlists
                        ('/poblesec/database/video/playlists',
                         'elisa.plugins.database.playlists_controller:recently_added_video_decorator'),
                        ('/poblesec/database/video/playlists',
                         'elisa.plugins.database.playlists_controller:most_played_video_decorator'),
                        ('/poblesec/database/video/playlists',
                         'elisa.plugins.database.playlists_controller:last_played_video_decorator'),
                        ('/poblesec/database/video/playlists',
                         'elisa.plugins.database.playlists_controller:unplayed_video_decorator'),
                        # music playlists
                        ('/poblesec/database/music/playlists',
                         'elisa.plugins.database.playlists_controller:recently_added_tracks_decorator'),
                        ('/poblesec/database/music/playlists',
                         'elisa.plugins.database.playlists_controller:most_played_tracks_decorator'),
                        ('/poblesec/database/music/playlists',
                         'elisa.plugins.database.playlists_controller:last_played_tracks_decorator'),
                        # image history
                        ('/poblesec/database/pictures/playlists',
                         'elisa.plugins.database.playlists_controller:recently_added_photos_decorator'),
                        ('/poblesec/database/pictures/playlists',
                         'elisa.plugins.database.playlists_controller:most_played_photos_decorator'),
                        ('/poblesec/database/pictures/playlists',
                         'elisa.plugins.database.playlists_controller:last_played_photos_decorator'),
                        ('/poblesec/browser',
                         'elisa.plugins.database.scanning_widget:scanning_decorator'),],
    cmdclass=cmdclass,
)
